%define dest_dir %{_libdir}/OpenBoard

Name:    openboard
Version: 1.6.1
Release: 1%{?dist}
Summary: cross-platform interactive whiteboard application
License: GPLv3
Url:     https://github.com/OpenBoard-org/OpenBoard
Source:  https://github.com/OpenBoard-org/OpenBoard/archive/v%{version}.tar.gz

# use system libs as dependencies
Patch0: openboard-1.6.1-no_Third-Party.patch

# use poppler instead of xpdf to handle pdf
#Patch1: openboard-XPDFRenderer_with_poppler.patch

Patch3: openboard-ffmpeg.patch
#Patch4: openboard-gcc8.patch
#Patch5: openboard-1.4.1-fix-build-with-qt-5.12.patch

#Patch6: openboard-poppler-0.72.patch
#Patch7: openboard-removegfalse.patch
#Patch8: openboard-poppler-0.83.patch

BuildRequires: redhat-lsb-core
BuildRequires: alsa-lib-devel
BuildRequires: bzip2-devel
BuildRequires: desktop-file-utils
%if 0%{?fedora} >= 30
BuildRequires: fdk-aac-free-devel
%else
BuildRequires: fdk-aac-devel
%endif


BuildRequires: ffmpeg-devel
BuildRequires: gcc-c++
BuildRequires: lame-devel
BuildRequires: libass-devel
BuildRequires: libogg-devel
BuildRequires: libpaper-devel
BuildRequires: libtheora-devel
BuildRequires: libva-devel
BuildRequires: libvorbis-devel
BuildRequires: libvpx-devel
BuildRequires: xz-devel
BuildRequires: openssl-devel
BuildRequires: opus-devel
BuildRequires: qtsingleapplication-qt5-devel
BuildRequires: quazip-qt5-devel
BuildRequires: t1lib-devel
BuildRequires: x264-devel
BuildRequires: xz-devel

BuildRequires: pkgconfig(Qt5Core)
BuildRequires: pkgconfig(Qt5Gui)
BuildRequires: pkgconfig(Qt5Help)
BuildRequires: pkgconfig(Qt5Multimedia)
BuildRequires: pkgconfig(Qt5MultimediaWidgets)
BuildRequires: pkgconfig(Qt5Network)
BuildRequires: pkgconfig(Qt5PrintSupport)
BuildRequires: pkgconfig(Qt5Script)
BuildRequires: pkgconfig(Qt5Svg)
BuildRequires: pkgconfig(Qt5UiTools)
BuildRequires: pkgconfig(Qt5WebKit)
BuildRequires: pkgconfig(Qt5WebKitWidgets)
BuildRequires: pkgconfig(Qt5Xml)
BuildRequires: pkgconfig(Qt5XmlPatterns)
BuildRequires: pkgconfig(libpulse-mainloop-glib)
BuildRequires: pkgconfig(libpulse)
BuildRequires: pkgconfig(hunspell)
BuildRequires: pkgconfig(freetype2)
BuildRequires: pkgconfig(openssl)
BuildRequires: pkgconfig(poppler)
BuildRequires: pkgconfig(poppler-cpp)
BuildRequires: pkgconfig(sdl)

%description
OpenBoard is an open-source cross-platform interactive whiteboard application 
designed primarily for use in schools. It was originally forked from Open-Sankoré, 
which was itself based on Uniboard.

%prep
%setup -q -n OpenBoard-%{version}
%patch0 -p1
#%patch1 -p1
%patch3 -p1
#%patch4 -p1
#%patch5 -p1
#%patch6 -p1
#%patch7 -p1
#%patch8 -p1

%build
%_qt5_bindir/lrelease -removeidentical OpenBoard.pro

%qmake_qt5 \
    INCLUDEPATH+=%_includedir/quazip5 \
    INCLUDEPATH+=%_includedir/poppler \
    INCLUDEPATH+=%_includedir/qt5/QtSolutions \
    OpenBoard.pro
%make_build

%install
make install
install -D -m 0644 resources/images/OpenBoard.png %{buildroot}%{_datadir}/pixmaps/openboard.png

# missing desktop file, creating one
mkdir -p %{buildroot}%{_datadir}/applications/
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=openboard
GenericName=whiteboard application
Comment=Interactive whiteboard for schools and universities
Exec=%{dest_dir}/run.sh "%f"
Icon=%{name}
StartupNotify=true
Terminal=false
Type=Application
MimeType=application/x-%{name};
Categories=Education
EOF

desktop-file-validate %{buildroot}%{_datadir}/applications/openboard.desktop

install -D -m 0755 build/linux/release/product/OpenBoard %{buildroot}%{dest_dir}/OpenBoard
cp -r build/linux/release/product/* %{buildroot}%{dest_dir}/

#run.sh (set env to avoid some possible issues)
cat > %{buildroot}%{dest_dir}/run.sh <<EOF
#!/bin/bash
# --------------------------------------------------------------------
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# ---------------------------------------------------------------------

env QT_PLUGIN_PATH=\$QT_PLUGIN_PATH:%{dest_dir}/%{name}/plugins LD_LIBRARY_PATH=\$LD_LIBRARY_PATH:%{dest_dir}/plugins/cffadaptor %{dest_dir}/OpenBoard "\$@"
EOF
chmod 0755 %{buildroot}%{dest_dir}/run.sh
mkdir -p %{buildroot}/%{_bindir}/
ln -s -T %{dest_dir}/run.sh %{buildroot}/%{_bindir}/%{name}

# clean some exe bits
find %{buildroot} -executable -type f -name *.js -exec chmod -x '{}' \+
find %{buildroot} -executable -type f -name *.svg -exec chmod -x '{}' \+
find %{buildroot} -executable -type f -name *.css -exec chmod -x '{}' \+
find %{buildroot} -executable -type f -name *.xml -exec chmod -x '{}' \+
find %{buildroot} -executable -type f -name *.html -exec chmod -x '{}' \+

# internalization
lrelease-qt5 -removeidentical OpenBoard.pro
mkdir -p %{buildroot}%{dest_dir}/i18n/
cp -R resources/i18n/OpenBoard*.qm %{buildroot}%{dest_dir}/i18n/

# customizations
cp -R resources/customizations %{buildroot}%{dest_dir}/


%files
%doc COPYRIGHT LICENSE
%{_datadir}/applications/openboard.desktop

%{_datadir}/pixmaps/openboard.png
%{_libdir}/OpenBoard
%{_bindir}/openboard

%changelog
* Thu Apr 22 2021 josef radinger <cheese@nosuchhost.net> - 1.6.1-1
- bump version
- remove patch1
- remove patch4
- remove patch5
- remove patch6
- remove patch7
- remove patch8

* Fri May 08 2020 josef radinger <cheese@nosuchhost.net> - 1.5.4-2
- fix build for poppler 0.84 (patch from Philippe Malinge <pmal@free.fr>)

* Fri Mar 20 2020 josef radinger <cheese@nosuchhost.net> - 1.5.4-1
- bump version

* Sat May 11 2019 josef radinger <cheese@nosuchhost.net> - 1.5.3-4
- switch to fdk-aac-free-devel for fedora >= 30

* Fri May 03 2019 josef radinger <cheese@nosuchhost.net> - 1.5.3-3
- fix build with qt-5.12 (patch5)
- fix build with poppler 0.72 (patch6)
- add patch7 to remove gFalse and friends

* Thu May 02 2019 josef radinger <cheese@nosuchhost.net> - 1.5.3-2
- use xz-devel instead of lzma-devel

* Sat Apr 13 2019 josef radinger <cheese@nosuchhost.net> - 1.5.3-1
- bump version
- remove patch2 (openssl) and patch5 (pen color)

* Sat Mar 30 2019 josef radinger <cheese@nosuchhost.net> - 1.5.2-2
- fix problem with colors not be shown at startup

* Sat Mar 30 2019 josef radinger <cheese@nosuchhost.net> - 1.5.2-1
- bump version
- bases on package for alt-linux

